<?php
$page_title = "Registration History";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="../img/logo.png" alt="iWallet"></a></h1>
				<form id="searchForm" action="" method="post">
					<div class="aside-heading">
						<div class="btns">
							<input type="button" id="btnSearchAll" value="All" class="btn bg-default px50 hi22">&nbsp;
							<input type="button" id="btnSearchToday" value="Today" class="btn bg-default px50 hi22">&nbsp;
							<input type="button" id="btnSearch" value="Search" class="btn bg-default px50 hi22">
						</div>
					</div>
					<table class="conditions fontS w100p">
						<colgroup>
							<col class="w50p">
							<col class="w50p">
						</colgroup>
						<tr>
							<th>Account Number</th>
							<td><input type="text" id="s_user_account" name="s_user_account" value="<?php $this -> echoSUserAccount() ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>IP Address</th>
							<td><input type="text" id="s_ip_address" name="s_ip_address" value="<?php $this -> echoSIPAddress() ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>Country</th>
							<td>
								<select id="s_country" name="country" class="w100p">
									<option value="">--- All ---</option>
									<?php $this -> echoCountry(); ?>
								</select>
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">Specify Date</span>
								<p>
									<?php $this -> dispLoginFlg(); ?>
									<input type="text" id="s_from" name="s_from" value="<?php $this -> echoFrom() ?>" class="px110" placeholder="日時"> 
									- <input type="text" id="s_to" name="s_to" value="<?php $this -> echoTo() ?>" class="px110" placeholder="">
								</p>
							</td>
						</tr>
					</table>

					<input type="hidden" value="" id="type" name="type" />
				</form>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
							<?php $this -> dispPager(); ?>
						</div>
						<?php $this -> echoMessage(); ?>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w100p fontXS calign">
								<tr>
									<th rowspan="" class="w10p">Login Time</th>
									<th class="w10p">Name</th>
									<th class="w10p">Account Number</th>
									<th rowspan="" class="w10p">IP Address</th>
									<th rowspan="" class="w10p">Country</th>
								</tr>
								<?php $this -> echoList(); ?>
							</table>

							<input type="hidden" value="" id="type" name="type" />
							<input type="hidden" value="" id="action" name="action" />
							<input type="hidden" id="detail_account" name="detail_account" />
						</form>
						<div class="article-bottom">
							<?php $this -> dispPager(); ?>
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="../js/registration_history.js"></script>
</body>
</html>